=======
Signals
=======

.. currentmodule:: pulsarbat

.. autosummary::
    :toctree: signals
    :template: signal_class.rst

    Signal
    RadioSignal
    IntensitySignal
    BasebandSignal
    FullStokesSignal
    DualPolarizationSignal
